@@ -20,10 +20,9 @@
 */
 
 #include "sentactionattribute.h"
-#include "helper_p.h"
 
-#include <QtCore/QDataStream>
-#include <QtCore/QSharedData>
+#include <QDataStream>
+#include <QSharedData>
 
 using namespace Akonadi;
 using namespace MailTransport;
